@@ -1312,7 +1312,7 @@ Ztring& Ztring::Date_From_Seconds_1970 (const int32s Value)
 Ztring& Ztring::Date_From_Seconds_1970 (const int64s Value)
 {
     time_t Time=(time_t)Value;
-    #if _POSIX_C_SOURCE >= 1 || _XOPEN_SOURCE || _BSD_SOURCE || _SVID_SOURCE || _POSIX_SOURCE
+    #if defined(HAVE_GMTIME_R)
     struct tm Gmt_Temp;
     struct tm *Gmt=gmtime_r(&Time, &Gmt_Temp);
     #elif defined(_MSC_VER)
@@ -1320,6 +1320,9 @@ Ztring& Ztring::Date_From_Seconds_1970 (const int64s Value)
     errno_t gmtime_s_Result=gmtime_s(&Gmt_Temp , &Time);
     struct tm* Gmt=gmtime_s_Result?NULL:&Gmt_Temp;
     #else
+    #ifdef __GNUC__
+    #warning "This version of ZenLib is not thread safe"
+    #endif
     struct tm *Gmt=gmtime(&Time);
     #endif
     if (!Gmt)
@@ -1352,7 +1355,7 @@ Ztring& Ztring::Date_From_Seconds_1970 (const int64s Value)
 Ztring& Ztring::Date_From_Seconds_1970_Local (const int32u Value)
 {
     time_t Time=(time_t)Value;
-    #if _POSIX_C_SOURCE >= 1 || _XOPEN_SOURCE || _BSD_SOURCE || _SVID_SOURCE || _POSIX_SOURCE
+    #if defined(HAVE_LOCALTIME_R)
     struct tm Gmt_Temp;
     struct tm *Gmt=localtime_r(&Time, &Gmt_Temp);
     #elif defined(_MSC_VER)
@@ -1360,10 +1363,15 @@ Ztring& Ztring::Date_From_Seconds_1970_Local (const int32u Value)
     errno_t localtime_s_Result=localtime_s(&Gmt_Temp , &Time);
     struct tm* Gmt=localtime_s_Result?NULL:&Gmt_Temp;
     #else
+    #ifdef __GNUC__
+    #warning "This version of ZenLib is not thread safe"
+    #endif
     struct tm *Gmt=localtime(&Time);
     #endif
     Ztring DateT;
     Ztring Date;
+    if (Gmt)
+    {
     Date+=Ztring::ToZtring((Gmt->tm_year+1900));
     Date+=__T("-");
     DateT.From_Number(Gmt->tm_mon+1); if (DateT.size()<2){DateT=Ztring(__T("0"))+Ztring::ToZtring(Gmt->tm_mon+1);}
@@ -1381,6 +1389,7 @@ Ztring& Ztring::Date_From_Seconds_1970_Local (const int32u Value)
     DateT.From_Number(Gmt->tm_sec); if (DateT.size()<2){DateT=Ztring(__T("0"))+Ztring::ToZtring(Gmt->tm_sec);}
     Date+=DateT;
     assign (Date.c_str());
+    }
     return *this;
 }
 
@@ -1643,18 +1652,23 @@ std::string Ztring::To_UTF8 () const
             case 6:
                 utf8chars[5] = 0x80 | (wc & 0x3f);
                 wc = (wc >> 6) | 0x4000000;
+                /* fallthrough */
             case 5:
                 utf8chars[4] = 0x80 | (wc & 0x3f);
                 wc = (wc >> 6) | 0x200000;
+                /* fallthrough */
             case 4:
                 utf8chars[3] = 0x80 | (wc & 0x3f);
                 wc = (wc >> 6) | 0x10000;
+                /* fallthrough */
             case 3:
                 utf8chars[2] = 0x80 | (wc & 0x3f);
                 wc = (wc >> 6) | 0x800;
+                /* fallthrough */
             case 2:
                 utf8chars[1] = 0x80 | (wc & 0x3f);
                 wc = (wc >> 6) | 0xc0;
+                /* fallthrough */
             case 1:
                 utf8chars[0] = (char) wc;
             }
@@ -1855,7 +1869,7 @@ int8s Ztring::To_int8s (int8u Radix, ztring_t Options) const
     {
         float80 F=To_float80();
         F-=I;
-        if (F>=0.5)
+        if (F>=0.5f)
             return (int8s)I+1;
     }
 
@@ -1893,7 +1907,7 @@ int8u Ztring::To_int8u (int8u Radix, ztring_t Options) const
     {
         float32 F=To_float32();
         F-=I;
-        if (F>=0.5)
+        if (F>=0.5f)
             return (int8u)I+1;
     }
 
@@ -1931,7 +1945,7 @@ int16s Ztring::To_int16s (int8u Radix, ztring_t Options) const
     {
         float80 F=To_float80();
         F-=I;
-        if (F>=0.5)
+        if (F>=0.5f)
             return (int16s)I+1;
     }
 
@@ -1969,7 +1983,7 @@ int16u Ztring::To_int16u (int8u Radix, ztring_t Options) const
     {
         float32 F=To_float32();
         F-=I;
-        if (F>=0.5)
+        if (F>=0.5f)
             return (int16u)I+1;
     }
 
@@ -2007,7 +2021,7 @@ int32s Ztring::To_int32s (int8u Radix, ztring_t Options) const
     {
         float80 F=To_float80();
         F-=I;
-        if (F>=0.5)
+        if (F>=0.5f)
             return I+1;
     }
 
@@ -2045,7 +2059,7 @@ int32u Ztring::To_int32u (int8u Radix, ztring_t Options) const
     {
         float32 F=To_float32();
         F-=I;
-        if (F>=0.5)
+        if (F>=0.5f)
             return I+1;
     }
 
@@ -2083,7 +2097,7 @@ int64s Ztring::To_int64s (int8u Radix, ztring_t Options) const
     {
         float32 F=To_float32();
         F-=I;
-        if (F>0.5)
+        if (F>0.5f)
             return I+1;
     }
 
@@ -2121,7 +2135,7 @@ int64u Ztring::To_int64u (int8u Radix, ztring_t Options) const
     {
         float32 F=To_float32();
         F-=I;
-        if (F>=0.5)
+        if (F>=0.5f)
             return I+1;
     }
 
